/*
 * This file is part of Goal Based City Growth (GBCG), which is a GameScript for OpenTTD
 * Copyright (C) 2016 Patrick Brennan
 *
 * GBCG is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * GBCG is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GBCG; If not, see <http://www.gnu.org/licenses/> or
 * write to the Free Software Foundation, Inc., 51 Franklin Street,
 * Fifth Floor, Boston, MA 02110-1301 USA.
 */

require("version.nut");

class MainClass extends GSInfo	{
	function GetAuthor()		{ return "Patrick Brennan"; }
	function GetName()			{ return "Goal Based City Growth"; }
	function GetShortName() 	{ return "GBCG"; }
	function GetDescription()	{ return "Meet goals to avoid penalties. Towns need cargo to grow or Terraform mars with OpenGFX Mars Industries."; }
	function GetURL()			{ return "https://www.tt-forums.net/viewtopic.php?f=65&t=75598"; }
	function GetVersion()		{ return SELF_VERSION; }
	function GetDate()			{ return "2016-12-23"; }
	function GetAPIVersion()	{ return "1.4"; }
	function MinVersionToLoad()	{ return 2; }
	function CreateInstance()	{ return "MainClass"; }
	function GetSettings() {

		AddSetting({ name = "industry_NewGRF",
				description = "Which industry set is being used?",
				easy_value = 8,
				medium_value = 8,
				hard_value = 8,
				custom_value = 8,
				flags = CONFIG_NONE, min_value = 1, max_value = 9 });
				
		AddLabels("industry_NewGRF", { _1 = "Baseset: Temperate",
					_2 = "Baseset: Arctic",
					_3 = "Baseset: Tropical",
					_4 = "FIRS: Temperate Basic",
					_5 = "FIRS: Arctic Basic",
					_6 = "FIRS: Tropic Basic",
					_7 = "FIRS: In A Hot Country",
					_8 = "FIRS: Extreme",
					_9 = "OpenGFX Mars Industries"});//bob mars

		AddSetting({ name = "goals_difficulty",
				description = "Difficulty setting (affects duration of goals, size of major goals)",
				easy_value = 1,
				medium_value = 2,
				hard_value = 3,
				custom_value = 3,
				flags = CONFIG_NONE, min_value = 1, max_value = 3 });
				
		AddLabels("goals_difficulty", { 	_1 = "Easy",
											_2 = "Medium",
											_3 = "Hard"});

    	AddSetting({ name = "start_major_town_goals",
                description="Number of major town growth goals to start the game",
                min_value=0,
                max_value=32,
                easy_value=1,
                medium_value=1,
                hard_value=1,
                custom_value=1,
                flags=GSInfo.CONFIG_NONE});

    	AddSetting({ name = "start_major_cargo_goals",
                description="Number of major raw material cargo pickup goals to start the game (NB: might be lower if duplicates created)",
                min_value=0,
                max_value=10,
                easy_value=2,
                medium_value=2,
                hard_value=2,
                custom_value=2,
                flags=GSInfo.CONFIG_NONE});

    	AddSetting({ name = "start_major_cargo_vertical_goals",
                description="Number of vertically integrated cargo pickup goals to be generated by each raw material industry cargo pickup goal (where possible)",
                min_value=0,
                max_value=3,
                easy_value=1,
                medium_value=3,
                hard_value=3,
                custom_value=3,
                flags=GSInfo.CONFIG_NONE});
				
		AddSetting({ name = "major_scale_factor",
				description = "Goal scale percentage of major cargo goals (easy = 50, normal = 80, hard = 350)",
				easy_value = 50,
				medium_value = 80,
				hard_value = 350,
				custom_value = 100,
				flags = CONFIG_INGAME, min_value = 1, max_value = 10000, step_size = 50 });
				
		AddSetting({ name = "minor_goal_chance",
                description="Chance of goals being generated each year (lower is more likely 0 - every year, 19 gives a one in twenty chance per year)",
                min_value=0,
                max_value=19,
                easy_value=15,
                medium_value=15,
                hard_value=15,
                custom_value=15,
                flags=GSInfo.CONFIG_NONE});
				
		AddSetting({ name = "minor_goals_per_year",
                description="Generate a random number of minor goals each year between 1 and this number (0 turns off minor goals)",
                min_value=0,
                max_value=10,
                easy_value=2,
                medium_value=2,
                hard_value=2,
                custom_value=2,
                flags=GSInfo.CONFIG_NONE});

    	AddSetting({name = "growth_weight",
                description="Percentage chance of a minor goal being a town/city growth goal (vs a cargo delivery goal)",
                min_value=0,
                max_value=100,
                easy_value=1,
                medium_value=1,
                hard_value=1,
                custom_value=1,
                flags=GSInfo.CONFIG_INGAME});

    	AddSetting({name = "pass_weight",
                description="(a) Likelihood that a minor cargo delivery goal will be passengers (=a/(a+b+(c*#cargoes))",
                min_value=1,
                max_value=20,
                easy_value=1,
                medium_value=1,
                hard_value=1,
                custom_value=1,
                flags=GSInfo.CONFIG_INGAME});

    	AddSetting({name = "mail_weight",
                description="(b) Likelihood that a minor cargo delivery goal will be mail (=b/(a+b+(c*#cargoes))",
                min_value=1,
                max_value=20,
                easy_value=1,
                medium_value=1,
                hard_value=1,
                custom_value=1,
                flags=GSInfo.CONFIG_INGAME});

   		AddSetting({name = "town_weight",
                description="(c) Likelihood that a minor cargo delivery goal will be freight (=c/(a+b+(c*#cargoes))",
                min_value=1,
                max_value=20,
                easy_value=1,
                medium_value=1,
                hard_value=1,
                custom_value=1,
                flags=GSInfo.CONFIG_INGAME});

		AddSetting({ name = "goal_scale_factor",
				description = "Difficulty level for growing towns/cities (easy = 60, normal = 100, hard = 140)",
				easy_value = 60,
				medium_value = 100,
				hard_value = 100,
				custom_value = 100,
				flags = CONFIG_INGAME, min_value = 1, max_value = 1000, step_size = 20 });

		AddSetting({ name = "use_town_sign",
				description = "Show growth rate text under town names",
				easy_value = 1,
				medium_value = 1,
				hard_value = 1,
				custom_value = 1,
				flags = CONFIG_BOOLEAN });

		AddSetting({ name = "town_growth_factor",
				description = "Expert setting: Town Growth Rate (TRG)",
				easy_value = 100,
				medium_value = 100,
				hard_value = 100,
				custom_value = 100,
				flags = CONFIG_INGAME, min_value = 20, max_value = 1000, step_size = 20 });

		AddSetting({ name = "supply_impacting_part",
				description = "Expert setting: Minimum supply percentage for TGR growth",
				easy_value = 50,
				medium_value = 50,
				hard_value = 50,
				custom_value = 50,
				flags = CONFIG_INGAME, min_value = 0, max_value = 100, step_size = 5 });

		AddSetting({ name = "exponentiality_factor",
				description = "Expert setting: TGR growth exponentiality factor",
				easy_value = 3,
				medium_value = 3,
				hard_value = 3,
				custom_value = 3,
				flags = CONFIG_INGAME, min_value = 1, max_value = 5 });

		AddSetting({ name = "lowest_town_growth_rate",
				description = "Expert setting: Lowest TGR if requirements are not meet",
				easy_value = 10000,
				medium_value = 10000,
				hard_value = 10000,
				custom_value = 10000,
				flags = CONFIG_INGAME, min_value = 1000, max_value = 30000, step_size = 1000 });

		AddSetting({ name = "log_level",
				description = "Debug: Log level (higher = print more)",
				easy_value = 1,
				medium_value = 1,
				hard_value = 1,
				custom_value = 3,
				flags = CONFIG_INGAME, min_value = 1, max_value = 3 });
		AddLabels("log_level", { _1 = "1: Info", _2 = "2: (unused)", _3 = "3: Debug" });

	}
}

RegisterGS(MainClass());
